# coding=utf-8
# Summary hub classes
#
# Copyright (C) 2011  Red Hat, Inc.
#
# This copyrighted material is made available to anyone wishing to use,
# modify, copy, or redistribute it subject to the terms and conditions of
# the GNU General Public License v.2, or (at your option) any later version.
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY expressed or implied, including the implied warranties of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.  You should have received a copy of the
# GNU General Public License along with this program; if not, write to the
# Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.  Any Red Hat trademarks that are incorporated in the
# source code or documentation are not subject to the GNU General Public
# License and may only be used or replicated with the express permission of
# Red Hat, Inc.
#
# Red Hat Author(s): Chris Lumens <clumens@redhat.com>
#
from pyanaconda.ui.gui.hubs import Hub
from pyanaconda.ui.lib.space import FileSystemSpaceChecker, DirInstallSpaceChecker
from pyanaconda.flags import flags
from pyanaconda.ui.gui.utils import gtk_call_once
from gi.repository import Gtk
import os

__all__ = ["SummaryHub"]

class SelectHub(Hub):
    builderObjects = ["selectWindow"]
    mainWidgetName = "selectWindow"
    uiFile = "hubs/select.glade"
    helpFile = "SelectHub.xml"

    def __init__(self, data, storage, payload, instclass):
        """Create a new Hub instance.

           The arguments this base class accepts defines the API that Hubs
           have to work with.  A Hub does not get free reign over everything
           in the anaconda class, as that would be a big mess.  Instead, a
           Hub may count on the following:

           ksdata       -- An instance of a pykickstart Handler object.  The
                           Hub uses this to populate its UI with defaults
                           and to pass results back after it has run.
           storage      -- An instance of storage.Storage.  This is useful for
                           determining what storage devices are present and how
                           they are configured.
           payload      -- An instance of a packaging.Payload subclass.  This
                           is useful for displaying and selecting packages to
                           install, and in carrying out the actual installation.
           instclass    -- An instance of a BaseInstallClass subclass.  This
                           is useful for determining distribution-specific
                           installation information like default package
                           selections and default partitioning.
        """
        super(SelectHub, self).__init__(data, storage, payload, instclass)
	self.radiobutton1 = self.builder.get_object("radiobutton1")
	self.radiobutton2 = self.builder.get_object("radiobutton2")
	self.radiobutton3 = self.builder.get_object("radiobutton3")
	self.radiobutton4 = self.builder.get_object("radiobutton4")
	self.checkbutton1 = self.builder.get_object("checkbutton1")
	self.checkbutton2 = self.builder.get_object("checkbutton2")
	self.checkbutton3 = self.builder.get_object("checkbutton3")
	self.checkbutton4 = self.builder.get_object("checkbutton4")
	self.checkbutton5 = self.builder.get_object("checkbutton5")
	self.box9 = self.builder.get_object("box9")
	self.notebook2 = self.builder.get_object("notebook2")
	self.notebook2.set_current_page(1)
	#self.quit = self.builder.get_object("quitButton")
	#self.nextbutton = self.builder.get_object("_nontinueButton")
	#Gtk.StyleContext.add_class(Gtk.Widget.get_style_context(self.nextbutton) ,"suggested-action")
	#Gtk.StyleContext.add_class(Gtk.Widget.get_style_context(self.quit) ,"neokylin-action")
        self.radiobutton_conf = "/tmp/radiobutton.conf"
        self.checkbutton_conf = "/tmp/checkbutton.conf"
	self.write_conf(self.radiobutton_conf,"radiobutton=1\n")
	self.write_conf(self.checkbutton_conf,"HTTPD=Y\n")
	print "init============================================================="
	self.checkbutton6 = Gtk.CheckButton("开发环境")
	self.checkbutton6.connect("toggled",self.on_develop_toggled,self.checkbutton6)
	self.develop = 0
	os.system("rm -rf /tmp/develop_packages.txt")



    def on_radiobutton1_toggled(self,button):
	self.notebook2.set_current_page(1)
	self.window.show_all()
	self.checkbutton1.show()
	self.checkbutton6.hide()
	self.write_conf(self.radiobutton_conf,"radiobutton=1\n")
    def on_radiobutton2_toggled(self,button):
	self.notebook2.set_current_page(1)
	self.window.show_all()
	self.checkbutton1.hide()
	self.checkbutton6.hide()
	self.write_conf(self.radiobutton_conf,"radiobutton=2\n")
    def on_radiobutton3_toggled(self,button):
	if not self.develop:
	    self.box9.add(self.checkbutton6)
	    self.develop = 1
	self.notebook2.set_current_page(1)
	self.window.show_all()
	self.checkbutton1.hide()
	self.write_conf(self.radiobutton_conf,"radiobutton=3\n")
    def on_radiobutton4_toggled(self,button):
	self.notebook2.set_current_page(0)
	self.window.show_all()
	self.checkbutton1.hide()
	self.checkbutton6.hide()
	self.write_conf(self.radiobutton_conf,"radiobutton=4\n")
    def on_continue_clicked(self,button):
	gtk_call_once(self.window.emit,"continue-clicked")
    def on_checkbutton_toggled(self,button):
	CHECKBUTTON=""
	if self.checkbutton1.get_active():
	    CHECKBUTTON = CHECKBUTTON + "KX=Y\n"
	if self.checkbutton2.get_active():
	    CHECKBUTTON = CHECKBUTTON + "HTTPD=Y\n"
	if self.checkbutton3.get_active():
	    CHECKBUTTON = CHECKBUTTON + "FTP=Y\n"
	if self.checkbutton4.get_active():
	    CHECKBUTTON = CHECKBUTTON + "DNS=Y\n"
	if self.checkbutton5.get_active():
	    CHECKBUTTON = CHECKBUTTON + "DHCP=Y\n"

	print CHECKBUTTON
	self.write_conf(self.checkbutton_conf,CHECKBUTTON)

    def on_develop_toggled(self,button,event):
	if self.checkbutton6.get_active():
            os.system("echo YES > /tmp/develop_packages.txt")
	else:
            os.system("rm -rf /tmp/develop_packages.txt")

    def write_conf(self,path,string):
	f = open(path,"w")
	f.write(string)
	f.close()





